<?php
/**
 * $Id: manages.php 63 2014-07-24 12:55:07Z Szablac $
 * @Project		Saxum Numerology Extension/Component
 * @author 		Laszlo Szabo
 * @package		Saxum Numerology
 * @copyright	Copyright (C) 2010 Saxum 2003 Bt. All rights reserved.
 * @license 	http://www.gnu.org/licenses/old-licenses/gpl-3.0.html GNU/GPL version 3
*/
// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die();

jimport( 'joomla.application.component.modellist' );

class SaxumnumerologyModelManages extends JModelList
{
	public function __construct($config = array())
	{
		if (empty($config['filter_fields'])) {
			$config['filter_fields'] = array(
				'id', 'a.id',
				'type', 'a.type_id' ,
				'name', 'a.name' ,
				'setname','a.set_id',
				'evaluation','a.eval_id', 
				'ordering', 'a.ordering', 
				'published', 'a.published'
			);
		}

		parent::__construct($config);
	}

	protected function getListQuery()
	{
		// Create a new query object.		
		$db = JFactory::getDBO();
		$query = $db->getQuery(true);
		// Select some fields
		$query->select(
			$this->getState(
				'list.select',
				'a.*'
				)
			);
		$query->from('#__saxumnumerology_manage a');
		
		$query->select('t.id as type_id,t.name as type');
		$query->join('INNER', '#__saxumnumerology_type t ON t.id=a.type_id');
		
		$query->select('s.id as set_id,s.name as setname');
		$query->join('INNER', '#__saxumnumerology_set s ON s.id=a.set_id');
		
		$query->select('e.id as eval_id,e.name as evaluation');
		$query->join('INNER', '#__saxumnumerology_evaluation e ON e.id=a.eval_id');
	
		// Filter by search in title.
		$search = $this->getState('filter.search');
		if (!empty($search))
		{
			if (stripos($search, 'id:') === 0)
			{
				$query->where('a.id = ' . (int) substr($search, 3));
			}
			elseif (stripos($search, 'name:') === 0)
			{
				$search = $db->quote('%' . $db->escape(substr($search, 5), true) . '%');
				$query->where('(a.name LIKE ' . $search . ')');
			}
			elseif (stripos($search, 'type:') === 0)
			{
				$search = $db->quote('%' . $db->escape(substr($search, 5), true) . '%');
				$query->where('(t.name LIKE ' . $search . ')');
			}
			elseif (stripos($search, 'set:') === 0)
			{
				$search = $db->quote('%' . $db->escape(substr($search, 4), true) . '%');
				$query->where('(s.name LIKE ' . $search . ')');
			}
			elseif (stripos($search, 'evaluation:') === 0)
			{
				$search = $db->quote('%' . $db->escape(substr($search, 11), true) . '%');
				$query->where('(e.name LIKE ' . $search . ')');
			}
			else
			{
				$search = $db->quote('%' . $db->escape($search, true) . '%');
				$query->where('(a.name LIKE ' . $search . ')');
			}
		}
		
		// Filter by type
		$typeId = $this->getState('filter.typeid');
		if (is_numeric($typeId)) {
			$query->where('a.type_id = '.(int) $typeId);
		}
			
		// Filter by published state
		$published = $this->getState('filter.published');
		if (is_numeric($published)) {
			$query->where('a.published = '.(int) $published);
		} else if ($published === '') {
			$query->where('(a.published IN (0, 1))');
		}
		

		$orderCol	= $this->state->get('list.ordering');
		$orderDirn	= $this->state->get('list.direction');
		$query->order($db->escape($orderCol.' '.$orderDirn));
		
		return $query;
	}
		
	protected function populateState($ordering = null, $direction = null)
	{
		// Initialise variables.
		$app = JFactory::getApplication('administrator');

		$search = $this->getUserStateFromRequest($this->context . '.filter.search', 'filter_search');
		$this->setState('filter.search', $search);
		
		// Load the filter state.
		$typeId = $this->getUserStateFromRequest($this->context.'.filter.typeid', 'filter_typeid', '');
		$this->setState('filter.typeid', $typeId);
		
		$state = $this->getUserStateFromRequest($this->context.'.filter.published', 'filter_published', '', 'string');
		$this->setState('filter.published', $state);
	
		// List state information.
		parent::populateState('ordering', 'asc');
	}

	public function getTypes()
	{
		// Create a new query object.
		$db		= $this->getDbo();
		$query	= $db->getQuery(true);

		$query->select('t.id, t.name AS type');
		$query->from('#__saxumnumerology_type AS t');
		$query->order('t.name ASC');

		$db->setQuery($query);
		$result = $db->loadObjectList();

		return $result;
	}		
}
  	
